// Copyright (c) 2018 GeometryFactory (France).
// All rights reserved.
//
// This file is part of CGAL (www.cgal.org).
//
// $URL: https://github.com/CGAL/cgal/blob/v6.1.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/do_no_use_CDT2.h $
// $Id: include/CGAL/Polygon_mesh_processing/internal/do_no_use_CDT2.h 08b27d3db14 $
// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
//
//
// Author(s)     : Sebastien Loriot

#ifndef CGAL_POLYGON_MESH_PROCESSING_INTERNAL_DO_NOT_USE_CDT2
#define CGAL_POLYGON_MESH_PROCESSING_INTERNAL_DO_NOT_USE_CDT2

#include <CGAL/license/Polygon_mesh_processing/meshing_hole_filling.h>


#define CGAL_TRIANGULATE_FACES_DO_NOT_USE_CDT2

#endif // CGAL_POLYGON_MESH_PROCESSING_INTERNAL_DO_NOT_USE_CDT2
